==> guildai-0.8.1rc1-py2.py3-none-any.whl: guild/tests/uat/guild-tests.md <==
# Guild tests

Guild tests can be run with the `check` command using the `-T` option
(`-n` here skips the general check info as we're just interested in
tests).

    >>> run("NO_SKIPPED_MSG=1 guild check -nT", timeout=1800) # doctest: +REPORT_UDIFF
    internal tests:
      additional-deps:             ok
      anonymous-models:            ok
      api:                         ok
      api-cmd:                     ok
      autocomplete:                ok
      batch-basics:                ok
      batch-custom-optimizer:      ok
      batch-error-handling:        ok
      batch-fail-on-trial-error:   ok
      batch-grid-search:           ok
      batch-guildfile-optimizers:  ok
      batch-handle-trial-status:   ok
      batch-implied-random:        ok
      batch-max-trials:            ok
      batch-needed:                ok
      batch-print-cmd:             ok
      batch-random-optimizer:      ok
      batch-random-seeds:          ok
      batch-restart:               ok
      batch-save-trials:           ok
      batch-skopt:                 ok
      batch-skopt2:                ok
      batch-skopt3:                ok
      batch-stage-trials:          ok
      batch-terminate:             ok
      breakpoints:                 ok
      cli:                         ok
      comments:                    ok
      compare:                     ok
      config:                      ok
      config-flags:                ok
      copy-sourcecode:             ok
      copy-sourcecode-warnings:    ok
      cpu-plugin:                  ok
      cross-package-inheritance:   ok
      debug-sourcecode:            ok
      delete-on-success:           ok
      dependencies:                ok
      dependencies-2:              ok
      dependencies-3:              ok
      disk-plugin:                 ok
      entry-points:                ok
      file-utils:                  ok
      filename-sorting:            ok
      flag-functions:              ok
      flag-utils:                  ok
      flag-vals:                   ok
      flagdefs:                    ok
      flags-dest:                  ok
      flags-sub-commands:          ok
      gpus:                        ok
      guild-home:                  ok
      guildfile-schema:            ok
      guildfiles:                  ok
      help:                        ok
      help-op:                     ok
      hiplot:                      ok
      hparam-summaries:            ok
      image-summaries:             ok
      import-flags:                ok
      imports:                     ok
      includes:                    ok
      index:                       ok
      init:                        ok
      ipy:                         ok
      isolate-runs-from-project:   ok
      keras:                       ok
      labels:                      ok
      locks:                       ok
      logging:                     ok
      long-run-names:              ok
      ls-cmd:                      ok
      ls-impl:                     ok
      marked-runs:                 ok
      memory-plugin:               ok
      model-proxies:               ok
      models:                      ok
      multi-run-deps:              ok
      namespaces:                  ok
      needed:                      ok
      notebook-exec:               ok
      notebooks:                   ok
      numeric-run-ids:             ok
      op-cmd:                      ok
      op-desc:                     ok
      op-env:                      ok
      op-errors:                   ok
      op-main:                     ok
      op-utils:                    ok
      opref:                       ok
      ops:                         ok
      package:                     ok
      plugins:                     ok
      project-api:                 ok
      publish-runs:                ok
      publish-templates:           ok
      python-utils:                ok
      pythonpath:                  ok
      query-parser:                ok
      quoted-flag-vals:            ok
      remotes:                     ok
      resource-flag-refs:          ok
      resource-flags:              ok
      restart-runs:                ok
      run-attrs:                   ok
      run-files:                   ok
      run-impl:                    ok
      run-labels:                  ok
      run-ops:                     ok
      run-output:                  ok
      run-scripts:                 ok
      run-status:                  ok
      run-stop:                    ok
      run-stop-after:              ok
      run-utils:                   ok
      run-with-proto:              ok
      runs-1:                      ok
      runs-2:                      ok
      scalars:                     ok
      select-resources:            ok
      select-runs:                 ok
      select-runs-2:               ok
      skopt:                       ok
      skopt-utils:                 ok
      sourcecode-digest:           ok
      startup-time:                ok
      step-checks:                 ok
      steps:                       ok
      steps-inherited-params:      ok
      steps-run-isolation:         ok
      summary:                     ok
      summary-utils:               ok
      tables:                      ok
      tags:                        ok
      tensorboard:                 ok
      test:                        ok
      test-flags:                  ok
      tfevents:                    ok
      timerange:                   ok
      utils:                       ok
      var:                         ok
      vcs-source:                  ok
      vcs-utils:                   ok
      view:                        ok
      yaml-utils:                  ok
    <exit 0>

==> guildai-0.8.2.dev1-py2.py3-none-any.whl: guild/tests/uat/guild-tests.md <==
# Guild tests

Guild tests can be run with the `check` command using the `-T` option
(`-n` here skips the general check info as we're just interested in
tests).

    >>> run("NO_SKIPPED_MSG=1 guild check -nT") # doctest: +REPORT_UDIFF
    internal tests:
      ac-support:                  ok
      additional-deps:             ok
      anonymous-models:            ok
      api:                         ok
      api-compare:                 ok
      api-help-op:                 ok
      api-merge:                   ok
      api-ops:                     ok
      api-runs:                    ok
      autocomplete-bash:           ok
      autocomplete-zsh:            ok
      batch-basics:                ok
      batch-custom-optimizer:      ok
      batch-error-handling:        ok
      batch-fail-on-trial-error:   ok
      batch-grid-search:           ok
      batch-guildfile-optimizers:  ok
      batch-handle-trial-status:   ok
      batch-implied-random:        ok
      batch-max-trials:            ok
      batch-needed:                ok
      batch-print-cmd:             ok
      batch-random-optimizer:      ok
      batch-random-seeds:          ok
      batch-restart:               ok
      batch-save-trials:           ok
      batch-skopt:                 ok
      batch-skopt2:                ok
      batch-skopt3:                ok
      batch-stage-trials:          ok
      batch-terminate:             ok
      breakpoints:                 ok
      cli:                         ok
      click-patch:                 ok
      comments:                    ok
      compare:                     ok
      config:                      ok
      config-flags:                ok
      copy-sourcecode:             ok
      copy-sourcecode-warnings:    ok
      cpu-plugin:                  ok
      cross-package-inheritance:   ok
      debug-sourcecode:            ok
      delete-on-success:           ok
      dependencies:                ok
      dependencies-2:              ok
      dependencies-3:              ok
      disk-plugin:                 ok
      entry-points:                ok
      file-utils:                  ok
      filename-sorting:            ok
      filter-parser:               ok
      filter-runs:                 ok
      filter-runs-impl:            ok
      flag-functions:              ok
      flag-utils:                  ok
      flag-vals:                   ok
      flagdefs:                    ok
      flags-dest:                  ok
      flags-sub-commands:          ok
      gpus:                        ok
      guild-home:                  ok
      guildfile-schema:            ok
      guildfiles:                  ok
      help:                        ok
      help-op:                     ok
      hiplot:                      ok
      hparam-summaries:            ok
      image-summaries:             ok
      import-flags:                ok
      imports:                     ok
      includes:                    ok
      index:                       ok
      init:                        ok
      ipy:                         ok
      isolate-runs-from-project:   ok
      keras:                       ok
      labels:                      ok
      locks:                       ok
      logging:                     ok
      long-run-names:              ok
      ls-cmd:                      ok
      ls-impl:                     ok
      manifest:                    ok
      marked-runs:                 ok
      memory-plugin:               ok
      merge-impl:                  ok
      model-proxies:               ok
      models:                      ok
      multi-run-deps:              ok
      namespaces:                  ok
      needed:                      ok
      notebook-exec:               ok
      notebooks:                   ok
      numeric-run-ids:             ok
      op-cmd:                      ok
      op-desc:                     ok
      op-env:                      ok
      op-errors:                   ok
      op-main:                     ok
      op-utils:                    ok
      opref:                       ok
      ops:                         ok
      package:                     ok
      plugins:                     ok
      project-api:                 ok
      publish-runs:                ok
      publish-templates:           ok
      python-script:               ok
      python-utils:                ok
      pythonpath:                  ok
      query-parser:                ok
      quoted-flag-vals:            ok
      r-script:                    ok
      remotes:                     ok
      resource-flag-refs:          ok
      resource-flags:              ok
      restart-runs:                ok
      run-attrs:                   ok
      run-files:                   ok
      run-impl:                    ok
      run-labels:                  ok
      run-manifest:                ok
      run-merge:                   ok
      run-ops:                     ok
      run-output:                  ok
      run-scripts:                 ok
      run-status:                  ok
      run-stop:                    ok
      run-stop-after:              ok
      run-utils:                   ok
      run-with-proto:              ok
      runs-1:                      ok
      runs-2:                      ok
      scalars:                     ok
      select-resources:            ok
      select-runs:                 ok
      select-runs-2:               ok
      skopt:                       ok
      skopt-utils:                 ok
      sourcecode-digest:           ok
      startup-time:                ok
      step-checks:                 ok
      steps:                       ok
      steps-inherited-params:      ok
      steps-run-isolation:         ok
      summary:                     ok
      summary-utils:               ok
      tables:                      ok
      tags:                        ok
      tensorboard:                 ok
      test:                        ok
      test-flags:                  ok
      tfevents:                    ok
      timerange:                   ok
      utils:                       ok
      var:                         ok
      vcs-source:                  ok
      vcs-utils:                   ok
      view:                        ok
      yaml-utils:                  ok
    <exit 0>
